"""
URL configuration for django_project project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/5.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
from django.conf import settings
from django.conf.urls.static import static

from myapp.views.authviews import login_view, logout_view
from myapp.views.userviews import register_view, account_view, delete_account_view, welcome_view, edit_account_view
from myapp.views.groupviews import group_list_view, group_create_view, group_update_view, group_delete_view, group_detail_view, group_search_view
from myapp.views.postviews import create_post_view, feed_view
from myapp.views.initview import init_db_view


urlpatterns = [
    path('admin/', admin.site.urls),
    path('register/', register_view, name='register'),
    path('', login_view, name='login'), # default view
    path('account/', account_view, name='account'),
    path('delete/', delete_account_view, name='delete_account'),
    path('logout/', logout_view, name='logout'),
    path('groups/', group_list_view, name='group_list'),
    path('groups/create/', group_create_view, name='group_create'),
    path('groups/<int:group_id>/update/', group_update_view, name='group_update'),
    path('groups/<int:group_id>/delete/', group_delete_view, name='group_delete'),
    path('groups/<int:group_id>/', group_detail_view, name='group_detail'),
    path('post/create/', create_post_view, name='create_post'),
    path('feed/', feed_view, name='feed'),
    path('welcome/', welcome_view, name='welcome'),
    path('edit_account/', edit_account_view, name='edit_account'),
    path('group_search', group_search_view, name='group_search')
]

if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
