mod models;
mod auth;
mod db;
use db::update_user;
use pyo3::prelude::*;
use pyo3::wrap_pyfunction;


#[pymodule]
fn rust_crud_api(_py: Python, m: &PyModule) -> PyResult<()> {
    m.add_class::<models::User>()?;
    m.add_class::<models::Group>()?;
    m.add_class::<models::Post>()?;
    // Authentication functions
    m.add_function(wrap_pyfunction!(auth::generate_jwt, m)?)?;
    m.add_function(wrap_pyfunction!(auth::verify_jwt, m)?)?;
    m.add_function(wrap_pyfunction!(auth::hash_password, m)?)?;
    m.add_function(wrap_pyfunction!(auth::verify_password, m)?)?;

    // Database functions
    m.add_function(wrap_pyfunction!(db::init::init_db, m)?)?;
    // Users
    m.add_function(wrap_pyfunction!(db::users::create_user, m)?)?;
    m.add_function(wrap_pyfunction!(db::users::get_user, m)?)?;
    m.add_function(wrap_pyfunction!(db::users::get_all_users, m)?)?;
    m.add_function(wrap_pyfunction!(db::users::update_user, m)?)?;
    m.add_function(wrap_pyfunction!(db::users::delete_user, m)?)?;
    m.add_function(wrap_pyfunction!(db::users::verify_user,m)?)?;
    m.add_function(wrap_pyfunction!(db::users::update_first_login,m)?)?;
    m.add_function(wrap_pyfunction!(db::users::update_user, m)?)?;

    // Groups
    m.add_function(wrap_pyfunction!(db::groups::create_group, m)?)?;
    m.add_function(wrap_pyfunction!(db::groups::get_group, m)?)?;
    m.add_function(wrap_pyfunction!(db::groups::get_all_groups, m)?)?;
    m.add_function(wrap_pyfunction!(db::groups::add_user_to_group, m)?)?;
    m.add_function(wrap_pyfunction!(db::groups::get_group_members, m)?)?;
    m.add_function(wrap_pyfunction!(db::groups::delete_group, m)?)?;
    m.add_function(wrap_pyfunction!(db::groups::search_groups, m)?)?;
    // Posts
    m.add_function(wrap_pyfunction!(db::posts::create_post, m)?)?;
    m.add_function(wrap_pyfunction!(db::posts::get_user_posts, m)?)?;
    m.add_function(wrap_pyfunction!(db::posts::get_group_posts, m)?)?;
    m.add_function(wrap_pyfunction!(db::posts::get_feed, m)?)?;
    Ok(())
}

